/*
 *  Copyright (c) 2015 The WebRTC project authors. All Rights Reserved.
 *
 *  Use of this source code is governed by a BSD-style license
 *  that can be found in the LICENSE file in the root of the source
 *  tree.
 *  Quelle: https://github.com/webrtc/samples/src/content/getusermedia/gum/js/main.js
 * https://github.com/webrtc/samples/tree/gh-pages/src/content/getusermedia/gum
 */
'use strict';

// Put variables in global scope to make them available to the browser console.
const constraints = window.constraints = {
  audio: true,
  video: true
};

function handleSuccess(stream) {
  const video = document.querySelector('video');
  const videoTracks = stream.getVideoTracks();
  console.log('Got stream with constraints:', constraints);
  console.log(`Using video device: ${videoTracks[0].label}`);
  window.stream = stream; // make variable available to browser console
  video.srcObject = stream;
}

function handleError(error) {
  if (error.name === 'ConstraintNotSatisfiedError') {
    let v = constraints.video;
    errorMsg(`Die Aufl&ouml;sung ${v.width.exact}x${v.height.exact} px wird von Ihrem Gerät nicht unterst&uuml;tzt.`);
  } else if (error.name === 'PermissionDeniedError') {
    errorMsg('Der Zugriff auf die Kamera und das Mikrofon wurde nicht erlaubt. ' +
      'Damit dieser Test funktioniert, müssen Sie &uuml;ber Ihren Browser ' +
      'Kamera und Mikrofon frei schalten.');
  }
  errorMsg(`getUserMedia error: ${error.name}`, error);
}

function errorMsg(msg, error) {
  const errorElement = document.querySelector('#errorMsg');
  errorElement.innerHTML += `<p>${msg}</p>`;
  if (typeof error !== 'undefined') {
    console.error(error);
  }
}

async function init(e) {
  try {
    const stream = await navigator.mediaDevices.getUserMedia(constraints);
    handleSuccess(stream);
    e.target.disabled = true;
  } catch (e) {
    handleError(e);
  }
}
document.querySelector('#showVideo').addEventListener('click', e => init(e));